#!/usr/bin/perl

use FDN::Sql::Structure;
use FDN::Common::Config;
use Getopt::Long;

sub print_help() {
	print STDERR "\nSyntax 1: $0 [-f <file>] -c <config>\n".
		"\t<file> config file name (relative to /etc/fdn) default check-db.cfg\n".
		"\t<config> config section name describing the database\n".
		"\nSyntax 2: $0 <action> [options]\n".
		"for action 'structure':\n".
		"\t--sql-file <file.sql>\t[+]\tAdd that file to the structure\n".
		"\t--db <name>  	\t[1]\tThe name of the database to process\n".
		"\t--force		\t\tDrop and recreate the whole databse\n".
		"\t--dry		\t\tdry-run\n".
		"\t\tdry_db:    do not create db\n".
		"\t\tdry_table: do not create/delete tables\n".
		"\t\tdry_alter: do not create/drop columns or index in tables\n".
		"\t\tdry_data:  do not create/delete/update data\n".
		"\t--run		\t\tOpposite to --dry, default\n".
		"[1] To be provided precisely one time, mandatory\n".
		"[+] At least one file, as many as you wish\n\n".
		"for action 'config' or 'create':\n".
		"\t--login <login>	\t[1]\tlogin used for mysql\n".
		"\t--passwd <passwd>    \t[?]\tpassword, default to 'toto'\n".
		"\t--db <name>  	\t[1]\tname of the database\n".
		"for 'config' only	\tfor 'create' only\n".
		"\t--type mysql 	\t--source host (default %)\n".
		"\t--utf8 perl  	\t\n".
		"\t--host localhost	\t\n".
		"[1] To be provided precisely one time, mandatory\n".
		"[?] optional\n\n";
	exit(1);
}

my $help = 0;

$result = GetOptions (
	'file=s' => \&set_config_file,
	'config=s' => \&set_config,
	'quiet' => \&set_quiet,
	'help'   => \$help,
	'dry' => sub { switch_option('dry',1,'all') },
	'run' => sub { switch_option('dry',0,'all') },
	);

print_help() if ( $help );

if ( $result ) {
	check_db();
	exit(0);
}

my $action = shift;

print_help() if ( ! defined $action );

my $result;
print "Action to perform is $action\n";
if ( $action eq 'structure' ) {
	$result = GetOptions (
		'sql-file=s{,}' => \&add_sql_file,
		'sql-filter=s{,}' => \&add_sql_filer,
		'db=s' => \&set_db_name,
		'force' => \&set_db_force,
		'help' => \$help,
		'dry' => sub { switch_option('dry',1,'all') },
		'dry_db' => sub { switch_option('dry',1,'db') } ,
		'dry_table' => sub { switch_option('dry',1,'table') },
		'dry_data' => sub { switch_option('dry',1,'data') },
		'dry_alter' => sub { switch_option('dry',1,'alter') },
		'run' => sub { switch_option('dry',0,'all') },
		'run_db' => sub { switch_option('dry',0,'db') } ,
		'run_table' => sub { switch_option('dry',0,'table') },
		'run_data' => sub { switch_option('dry',0,'data') },
		'run_alter' => sub { switch_option('dry',0,'alter') },
	);
} elsif ( $action eq 'create' ) {
	$result = GetOptions (
		'help' => \$help,
		'db=s' => \&set_db_name,
		'login=s' => \&set_login,
		'passwd=s' => \&set_passwd,
		'source=s' => \&set_source,
		'config=s' => \&set_config,
		'dry' => sub { switch_option('dry',1,'all') },
		'run' => sub { switch_option('dry',0,'all') },
	);
} elsif ( $action eq 'config' ) {
	$result = GetOptions (
		'help' => \$help,
		'db=s' => \&set_db_name,
		'login=s' => \&set_login,
		'passwd=s' => \&set_passwd,
		'utf8=s' => \&set_utf8,
		'type=s' => \&set_type,
		'host=s' => \&set_host,
		'config=s' => \&set_config,
		'dry' => sub { switch_option('dry',1,'all') },
		'run' => sub { switch_option('dry',0,'all') },
	);
}

if ( ! $result || $help ) {
	print STDERR "Unknown action $action\n";
	print_help;
	exit(2);
}

if ( ! control_options($action) ) {
	exit(1);
}

$subst->{'MAIN_DOM'} = Config_Key('/etc/gcmp/common.cfg','domains','main');

check_db($action);



